@@ -8,10 +8,8 @@ from .position import Position
 from .order import Order
 from .current_data import CurrentDataCacheDict
 from .instrument import Instrument
-from pqsdk.api import get_history
-from pqsdk import log
-import pqsdk.faxconstant as faxconstant
-from pqsdk.api import get_factor, get_attribute_history, get_previous_trading_date
+from pqsdk import log, pqconstant
+from pqsdk.api import *
 from .run_info import RunInfo
 
 
@@ -74,7 +72,7 @@ class StrategyContext(AbstractStrategyContext):
                       "add_time": order.add_time,
                       "trade_date": order.add_time.strftime('%Y-%m-%d')}
         self.orders.append(order_dict)
-        log.debug(f"order: {order_dict}")
+        # log.debug(f"order: {order_dict}")
 
     def plot_line(self, sec_code: str, name: str, value: float, desc=None):
         """
@@ -203,6 +201,26 @@ class StrategyContext(AbstractStrategyContext):
         """
         self.__tf.add_timer(callback=func, kwargs={"context": self}, when=time_str)
 
+    def run_minutely(self, func: Callable, time_str: str, minutes: int = 1) -> None:
+        """
+        每天内何时开始，间隔n分钟执行
+
+        :param func: 一个自定义的函数, 此函数必须接受context参数;例如自定义函数名market_open(context)
+        :param time_str: 具体执行时间,一个字符串格式的时间, 24小时内的任意时间，例如"10:00", "01:00"；
+        :param minutes: 间隔执行的分钟数
+        """
+        self.__tf.add_timer(callback=func, kwargs={"context": self}, when=time_str, minutes=minutes)
+
+    def run_secondly(self, func: Callable, time_str: str, seconds: int = 1) -> None:
+        """
+        每天内何时开始，间隔n秒执行
+
+        :param func: 一个自定义的函数, 此函数必须接受context参数;例如自定义函数名market_open(context)
+        :param time_str: 具体执行时间,一个字符串格式的时间, 24小时内的任意时间，例如"10:00", "01:00"；
+        :param seconds: 间隔执行的秒数
+        """
+        self.__tf.add_timer(callback=func, kwargs={"context": self}, when=time_str, seconds=seconds)
+
     def cancel(self, order, force: bool = False):
         pass
 
@@ -516,6 +534,177 @@ class StrategyContext(AbstractStrategyContext):
         """
         return []
 
+    def get_last_ticks(self, sec_code_lst: list, index: bool = False, fields: list = None):
+        """
+        获取当前最新的Tick数据。
+        注意：不是历史某个回测时间点的Tick数据。
+
+        :param sec_code_lst:
+        :param fields: 返回的字段列表
+        :param index: 是否设置sec_code为Index
+        :return:
+                [{
+                'sec_code', 股票代码
+                ’datetime'  tick时间字符串： %Y-%m-%d %H:%M:%S
+                'open', 当日开盘价
+                'high', 当日收盘价
+                'low', 当日最低价
+                'last_price', 当日最新价格
+                'pre_close', 昨日收盘价
+                'volume', 当日成交量，单位：手
+                'amount', 当日成交额
+                }]
+        """
+        df = get_last_ticks(sec_code_lst=sec_code_lst, index=index, fields=fields)
+        return df
+
+    def get_plate_data(self, trade_date: str = None, end_time: str = "15:00", limit: int = 3) -> pd.DataFrame:
+        """
+        获取板块列表
+
+        :param trade_date: 指定交易日的板块列表
+        :param end_time: 指定板块排名的时间节点，从09:25开始到15:30结束，每个间隔5分钟
+        :param limit: 按照板块强度倒序排名的板块数量
+        :return:
+        """
+        return get_plate_data(trade_date=trade_date, end_time=end_time, limit=limit)
+
+    def get_plate_members_lst(self, plate_code_list: list, trade_date: str = None):
+        """
+        获取板块的成分股
+        :param plate_code_list:
+        :param trade_date:
+        :return:
+        """
+        return get_plate_members_lst(plate_code_list=plate_code_list, trade_date=trade_date)
+
+    def get_stock_name(self, sec_code: str, trade_date: str = None):
+        """
+        获取股票代码的最新名称
+
+        :param sec_code:
+        :param trade_date:
+            None：默认为当天，如果当天不是交易日，则获取上一个交易日。
+            'YYYY-mm-dd'：具体日期的最新股票名称
+        :return: 股票名称
+        """
+        return get_stock_name(sec_code=sec_code, trade_date=trade_date)
+
+    def get_stock_price(self,
+                        sec_code: str,
+                        trade_date: str = None,
+                        end_time: str = None,
+                        dividend_type: str = "front"):
+        """
+        获取最新的股票价格
+
+        :param dividend_type: 复权选项(对股票/基金的价格字段、成交量字段及factor字段生效)
+                    'front'
+                    : 前复权, 默认是前复权
+                    none
+                    : 不复权, 返回实际价格
+                    'back'
+                    : 后复权
+        :param trade_date: 指定交易日, 格式: 2024-07-15
+        :param end_time: 如果trade_date不是系统日期当日，可以指定历史数据的具体分钟，格式：09:30
+        :param sec_code:
+        :return:
+        """
+        return get_stock_price(sec_code=sec_code,
+                               trade_date=trade_date,
+                               end_time=end_time,
+                               dividend_type=dividend_type)
+
+    def get_price_limit(self,
+                        sec_code: str,
+                        trade_date: str = None,
+                        dividend_type: str = "front"):
+        """
+        股票代码涨跌停价格
+        假设：
+        - 600xxx, 601xxx, 603xxx：上海主板，涨跌停限制10%
+        - 000xxx：深圳主板，涨跌停限制10%
+        - 002xxx：深圳中小板，涨跌停限制10%
+        - 300xxx：深圳创业板，涨跌停限制20%
+        - 688xxx：上海科创板，涨跌停限制20%
+
+        :param dividend_type: 复权选项(对股票/基金的价格字段、成交量字段及factor字段生效)
+                    'front'
+                    : 前复权, 默认是前复权
+                    none
+                    : 不复权, 返回实际价格
+                    'back'
+                    : 后复权
+        :param sec_code:
+        :param trade_date: 指定日期的涨跌停价格
+        :return: (昨日收盘价格, 今日涨停价, 今日跌停价)
+        """
+        return get_price_limit(sec_code=sec_code,
+                               trade_date=trade_date,
+                               dividend_type=dividend_type)
+
+    def get_auction_data(self,
+                         security: str,
+                         count: int = None,
+                         unit: str = '1m',
+                         trade_date: str = None,
+                         start_datetime: str = None,
+                         end_datetime: str = None,
+                         fields=None):
+        """
+        获取股票的集合竞价数据。
+
+        :param security: 股票代码
+        :param count: 返回行数
+        :param unit: 支持1m, 5m
+        :param trade_date: 交易日
+        :param start_datetime: 开始时间
+        :param end_datetime: 结束时间
+        :param fields: 获取字段，范围：['open', 'high', 'low', 'close', 'pre_close']
+        :return:
+        """
+        return get_auction_data(security=security,
+                                count=count,
+                                unit=unit,
+                                trade_date=trade_date,
+                                start_datetime=start_datetime,
+                                end_datetime=end_datetime,
+                                fields=fields)
+
+    def get_orders(self, trade_date: str = None, is_buy: bool = None, include_canceled: bool = True):
+        """
+        获取交易日的委托单，返回DataFrame
+
+        :param include_canceled: 是否包括已撤的委托
+        :param trade_date:
+        :param is_buy:
+        :return: DataFrame,
+            字段：['order_code', 委托编号
+                'sec_code',  股票代码
+                'order_time', 委托时间
+                'is_buy', 委托买卖方向：买单=1， 卖单=0
+                'order_volume',  委托数量
+                'order_price']  委托价格
+        """
+        df = pd.DataFrame(self.orders)
+        df.rename(columns={"order_id": "order_code",
+                           "add_time": "order_time",
+                           "volume": "order_volume",
+                           "price": "order_price"}, inplace=True)
+
+        if trade_date:
+            df = df[df['trade_date'] == trade_date]
+
+        if not df.empty:
+            if is_buy is not None:
+                df = df[df['is_buy'] == is_buy]
+
+            df['is_buy'] = df['is_buy'].apply(lambda x: 1 if True else 0)
+
+            # 与实盘保持输出一致
+            df = df[['order_code', 'sec_code', 'order_time', 'is_buy', 'order_volume', 'order_price']]
+        return df
+
     def set_benchmark_value(self, value: float):
         """
         设置回测过程中当前日期的benchmark的收益率
@@ -581,13 +770,13 @@ class StrategyContext(AbstractStrategyContext):
             if size < 100:
                 content = f"策略名称={self.strategy_name}, 类型=Buy, 股票代码={stock_code}, " \
                           f"目标市值={target}, 持仓市值={market_value}, " \
-                          f"委托价格={price},交易股数不足100股，放弃交易"
+                          f"委托价格={round(price, 2)},交易股数不足100股，放弃交易"
                 log.warning(content)
                 return None  # 未满足交易条件
             else:
                 return self.buy(stock_code=stock_code,
                                 volume=size,
-                                price_type=faxconstant.FIX_PRICE,
+                                price_type=pqconstant.FIX_PRICE,
                                 price=price,
                                 force=force)
 
@@ -601,24 +790,24 @@ class StrategyContext(AbstractStrategyContext):
             if size < 100:
                 content = f"策略名称={self.strategy_name}, 类型=Sell, 股票代码={stock_code}, " \
                           f"目标市值={target}, 持仓市值={market_value}, 持仓可用数量={position.can_use_volume}，" \
-                          f"委托价格={price},委托数量={size}, 交易股数不足100股，放弃交易"
+                          f"委托价格={round(price, 2)},委托数量={size}, 交易股数不足100股，放弃交易"
                 log.warning(content)
                 return None  # 未满足交易条件
             else:
                 if position.can_use_volume >= size >= 100:
                     content = f"策略名称={self.strategy_name}, 类型=Sell, 股票代码={stock_code}, " \
                               f"目标市值={target}, 持仓市值={market_value}, " \
-                              f"委托价格={price}, 持仓可用数量={position.can_use_volume}， 委托数量={size}"
+                              f"委托价格={round(price, 2)}, 持仓可用数量={position.can_use_volume}， 委托数量={size}"
                     log.debug(content)
                     return self.sell(stock_code=stock_code,
                                      volume=size,
-                                     price_type=faxconstant.FIX_PRICE,
+                                     price_type=pqconstant.FIX_PRICE,
                                      price=price,
                                      force=force)
                 else:
                     content = f"策略名称={self.strategy_name}, 类型=Sell, 股票代码={stock_code}, " \
                               f"目标市值={target}, 持仓市值={market_value}, " \
-                              f"委托价格={price},持仓数量={position.volume}, 委托数量={size}, " \
+                              f"委托价格={round(price, 2)},持仓数量={position.volume}, 委托数量={size}, " \
                               f"可用数量（{position.can_use_volume}）不足，放弃交易"
                     log.warning(content)
                     return None  # 未满足交易条件
@@ -717,7 +906,7 @@ class StrategyContext(AbstractStrategyContext):
     def buy(self,
             stock_code: str,
             volume: int,
-            price_type: int = faxconstant.FIX_PRICE,
+            price_type: int = pqconstant.FIX_PRICE,
             price: float = None,
             force: bool = False):
         """
@@ -730,7 +919,7 @@ class StrategyContext(AbstractStrategyContext):
         :return:
         """
         # 获取价格
-        if price_type != faxconstant.FIX_PRICE or price is None:
+        if price_type != pqconstant.FIX_PRICE or price is None:
             # trade_date = self.current_dt.strftime('%Y-%m-%d')
             if self.unit in ['1d']:
                 trade_date = self.current_dt.strftime('%Y-%m-%d')
@@ -784,7 +973,7 @@ class StrategyContext(AbstractStrategyContext):
     def sell(self,
              stock_code: str,
              volume: int,
-             price_type: int = faxconstant.FIX_PRICE,
+             price_type: int = pqconstant.FIX_PRICE,
              price: float = None,
              force: bool = False):
         """
@@ -797,7 +986,7 @@ class StrategyContext(AbstractStrategyContext):
         :return:
         """
         # 获取价格
-        if price_type != faxconstant.FIX_PRICE or price is None:
+        if price_type != pqconstant.FIX_PRICE or price is None:
             # trade_date = self.current_dt.strftime('%Y-%m-%d')
             if self.unit in ['1d']:
                 trade_date = self.current_dt.strftime('%Y-%m-%d')
