@@ -19,7 +19,14 @@ import_modules(api)
 
 
 class BacktestExecutor:
-    def __init__(self, kwargs: dict):
+    def __init__(self, kwargs: dict, task=None):
+        """
+
+        :param kwargs:
+        :param task: celery task
+        """
+
+        self.task = task
 
         # 策略参数, 从list转换为dict， 根据数据推断，把value转换为正确的数据类型
         # self.strategy_params = {param['key']: convert_to_type(param['value']) for param in kwargs.get('parameters')}
@@ -47,7 +54,7 @@ class BacktestExecutor:
             # 行情基准-运行周期，支持1d，1m，5m，即根据行情基准-证券代码的k线图，按照1d,1m执行handle_bar()函数
             unit=self.strategy_params.get('unit', '1d'),
             # 除权方式，, 支持none：不复权，front：前复权，back：后复权
-            dividend_type=self.strategy_params.get('dividend_type', 'back'),
+            dividend_type=self.strategy_params.get('dividend_type', 'front'),  # 默认前复权
             strategy_file=kwargs.get('strategy_file', None),  # 策略代码文件
             strategy_script=kwargs.get('script', None),  # 策略代码
             parameters=self.strategy_params,  # dict类型，策略中可以访问到到自定义参数列表
@@ -248,6 +255,9 @@ class BacktestExecutor:
                                               end_date=self.params['end_date'],
                                               unit=self.params['unit'])
 
+        # 按照回测的时间序列向后补充数据，如果有缺失的话
+        df = df.reindex(time_range, method='ffill')
+
         # 设置context.dt为默认的第一天，因为initialize()或者process_initialize()可能会用到
         self.context.set_dt(time_range[0])
 
@@ -270,7 +280,24 @@ class BacktestExecutor:
         # 按照回测时间范围的交易日播放进行回测
         trade_date = None  # 当前的日期
         is_open_trade_date = False  # 是否为交易日
-        for trade_time in tqdm(time_range):
+        total = len(time_range)
+        run_start_dt = datetime.datetime.now()  # 用于估算回测还剩余多少时间
+        # 使用 enumerate() 和 tqdm()
+        for index, trade_time in enumerate(tqdm(time_range, total=len(time_range))):
+            # 在这里你可以使用 index 和 trade_time
+            # 注意：由于 tqdm 是基于迭代器工作的，它实际上并不需要 total 参数来正确工作，
+            # 但提供 total 可以让进度条更准确地显示。
+            # 如果不知道长度，可以省略 total 参数，但进度条可能不会非常准确。
+            # 这里的 trade_time 实际上是枚举的值（即 range 中的数字）
+
+            # task打点进度
+            if self.task is not None:
+                run_current_dt = datetime.datetime.now()
+                run_delta = (run_current_dt - run_start_dt).seconds
+                self.task.update_state(meta={"current": index + 1,
+                                             "estimate_left_time": int(run_delta/(index + 1) * (total - index - 1)),
+                                             "total": total})
+
             # new trade date, 每天执行一次after_trading_end()，最后一次在for循环结束后执行
             if trade_date is not None and trade_time.strftime('%Y-%m-%d') != trade_date:
                 # 每日收盘后执行，必须在更新设置context之前执行
